package fishrungames.bashgid.core;

import java.util.ArrayList;

import fishrungames.bashgid.MainActivity;

public class NewsManager {

	private static NewsManager instance = null;
	
	
	public static NewsManager GetInstance()
	{
		if (instance == null)
		{
			instance = new NewsManager();
		}
		
		return instance;
	}
	
	
	public static class NewsRecord
	{
		public String title;
		public String description;
		public String imageId;
		
		public NewsRecord(String title, String description, String imageId)
		{
			this.title = title;
			this.description = description;
			this.imageId = imageId;
		}
		
		NewsRecord(RssReader.Rss2Item rss2Item)
		{
			this.title = rss2Item.title;
			this.description = rss2Item.description;
			
			if ((rss2Item.rss2Enclosure != null) && (DownloadManager.MimeTypeIsImage(rss2Item.rss2Enclosure.mimeType)))
			{
				this.imageId = rss2Item.rss2Enclosure.url;
			}
			else
			{
				this.imageId = "R.drawable.transparent";
			}
		}
	}
	
	ArrayList<NewsRecord> newsRecord = new ArrayList<NewsRecord>();
	
	public RemoveCallbackInterface DownloadNews(NewsUpdatedCallbackInterface callback)
	{
		
		DownloadNewsRunnable downloadNewsRunnable = new DownloadNewsRunnable(callback);
		
		Thread thread = new Thread(downloadNewsRunnable);
		
		thread.start();
		
		return downloadNewsRunnable;
	}
	
	class DownloadNewsRunnable implements Runnable, RemoveCallbackInterface
	{
		
		NewsUpdatedCallbackInterface callback;
		
		public DownloadNewsRunnable(NewsUpdatedCallbackInterface callback)
		{
			this.callback = callback;
		}
		
		@Override
		public void RemoveCallback()
		{
			callback = null;
		}
		
		@Override
		public void run()
		{
			String xmlCode = DownloadManager.getXmlFromUrl("http://www.bashinform.ru/rss/all.xml");
			
			if (xmlCode == null)
			{
				return;
			}
			
			RssReader rssReader = new RssReader();
			
			rssReader.ReadRss(xmlCode);
			
			ArrayList<NewsRecord> localNewsRecord = new ArrayList<NewsRecord>();
			
			for (RssReader.Rss2Item rss2Item : rssReader.rss2ItemArr)
			{
				if (rss2Item.rss2Enclosure != null)
				{
					if (DownloadManager.MimeTypeIsImage(rss2Item.rss2Enclosure.mimeType))
					{
						ImageManager.getInstance().DownloadImageIfNeeded(rss2Item.rss2Enclosure.url);
					}
				}
			}
			
			for (RssReader.Rss2Item rss2Item : rssReader.rss2ItemArr)
			{
				localNewsRecord.add(new NewsRecord(rss2Item));
			}
			
			//Xperimental -- need mutex right here
			newsRecord = localNewsRecord;
			
			MainActivity.getInstance().newsDataSource.replaceNews(newsRecord);
			
			//Xperimental -- need mutex here, too
			if (callback != null)
			{
				callback.OnNewsUpdated();
			}
		}
	}
	
	public static interface NewsUpdatedCallbackInterface
	{
		public void OnNewsUpdated();
	}
	
	public static interface RemoveCallbackInterface
	{
		public void RemoveCallback();
	}
	
	
	public NewsManager()
	{
		/*
		newsRecord.add(new NewsRecord("Власти Башкирии создадут выезд из Уфы на трассу М-5 «Урал»", "Власти Башкирии создадут выезд из Уфы на трассу М-5 «Урал»", "R.drawable.news_image1"));
		newsRecord.add(new NewsRecord("Башкирия заняла первое место индекса «деловой активности»", "Башкирия заняла первое место индекса «деловой активности»", "R.drawable.news_image2"));
		newsRecord.add(new NewsRecord("«Салават Юлаев» обыграл «Ладу» и прервал серию из 5 поражений в КХЛ", "«Салават Юлаев» обыграл «Ладу» и прервал серию из 5 поражений в КХЛ", "R.drawable.news_image3"));
	*/
		newsRecord = MainActivity.getInstance().newsDataSource.getNews();
		
	}
	
	
	public ArrayList<NewsRecord> getNews()
	{
		return newsRecord;
	}
	
	
	
	
}
